# Changes

## v0.3.2 (2025-09-03)

### Fix

- **deps**: update dependency pydantic to >=2.11.3,<3.0.0
- **deps**: update dependency pydantic to >=2.11.2,<3.0.0

### Refactor

- migrate black/flake8 -> ruff
- migrate from poetry -> uv

## v0.3.1 (2025-04-03)

### Fix

- set correct repo urls

## v0.3.0 (2025-04-03)

### Feat

- support Django 5.2. Drop Django 5.0

### Fix

- **deps**: update dependency pydantic to >=2.11.0,<3.0.0

### Refactor

- add pyupgrade / django-upgrade precommit hooks

## v0.2.0 (2025-03-12)

### Feat

- change pkg name to django-sns-view2 for pypi publishing
- migrate from pyOpenSSL to cryptography
- add type annotations
- fork [django-sns-view](https://github.com/deep-c/django-sns-view) to begin bringing it up to date

### Fix

- pin OpenSSL version to fix tests

## v0.1.2 (2018-04-15)
